From: Jan Kiszka <jan.kiszka@siemens.com>
To: Jeroen Van den Keybus <jeroen.vandenkeybus@gmail.com>
Cc: "xenomai@xenomai.org" <xenomai@xenomai.org>
Subject: Re: [Xenomai] xeno3_rc3 - Watchdog detected hard LOCKUP
Date: Wed, 22 Apr 2015 07:14:49 +0200 [thread overview]
Message-ID: <55372E49.10106@siemens.com> (raw)
In-Reply-To: <CAPRPZsAjhPeDboNL7fdzwjm2cYVx-rVURbFzATgWi11o5f2Meg@mail.gmail.com>
On 2015-04-21 23:14, Jeroen Van den Keybus wrote:
> Sorry to tell, but it happened again after 181 hours.
>
> Of course, we can try to disable APEI (but not in BIOS AFAICT) but
> maybe it's better to find the root cause. I double checked that the
> patch is included in this kernel. The disassembly shows it's there
> allright. Hope you can make more out of it.
Yeah, too bad, I missed on turn of the code. This should work better:
diff --git a/lib/ioremap.c b/lib/ioremap.c
index f5331c0..1575d3e 100644
--- a/lib/ioremap.c
+++ b/lib/ioremap.c
@@ -88,9 +88,9 @@ int ioremap_page_range(unsigned long addr,
break;
} while (pgd++, addr = next, addr != end);
/* APEI may invoke this for temporarily remapping pages in NMI
* context - nothing we can and need to propagate globally. */
- if (!in_nmi()) {
+ if (!in_interrupt()) {
__ipipe_pin_range_globally(start, end);
flush_cache_vmap(start, end);
}
@@ -88,9 +88,9 @@ int ioremap_page_range(unsigned long addr,
break;
} while (pgd++, addr = next, addr != end);
- /* APEI may invoke this for temporarily remapping pages in NMI
+ /* APEI may invoke this for temporarily remapping pages in interrupt
* context - nothing we can and need to propagate globally. */
Jan
--
Siemens AG, Corporate Technology, CT RTC ITP SES-DE
Corporate Competence Center Embedded Linux
next prev parent reply other threads:[~2015-04-22 5:14 UTC|newest]
Thread overview: 32+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-02-26 10:08 [Xenomai] xeno3_rc3 - Watchdog detected hard LOCKUP Niels Wellens
2015-02-26 10:20 ` Gilles Chanteperdrix
[not found] ` <54EF0790.3040607@triphase.com>
2015-02-27 14:10 ` Niels Wellens
2015-02-27 20:32 ` Jan Kiszka
2015-02-27 20:36 ` Gilles Chanteperdrix
2015-02-27 20:39 ` Jan Kiszka
2015-03-03 8:11 ` Jan Kiszka
2015-03-04 20:35 ` Jeroen Van den Keybus
2015-03-09 14:56 ` Niels Wellens
2015-03-12 20:52 ` Jan Kiszka
2015-03-13 16:25 ` Jan Kiszka
2015-03-13 16:34 ` Gilles Chanteperdrix
2015-03-13 17:09 ` Jan Kiszka
2015-03-13 17:12 ` Gilles Chanteperdrix
2015-04-02 18:47 ` Jeroen Van den Keybus
2015-04-02 19:15 ` Gilles Chanteperdrix
2015-04-02 19:29 ` Jeroen Van den Keybus
2015-04-02 20:41 ` Gilles Chanteperdrix
2015-04-08 21:02 ` Jeroen Van den Keybus
2015-04-09 9:04 ` Jan Kiszka
2015-04-09 9:14 ` Jan Kiszka
2015-04-09 9:26 ` Jan Kiszka
2015-04-09 12:41 ` Gilles Chanteperdrix
2015-04-09 12:49 ` Jan Kiszka
2015-04-09 12:56 ` Gilles Chanteperdrix
2015-04-09 12:58 ` Gilles Chanteperdrix
2015-04-09 13:01 ` Jan Kiszka
2015-04-21 21:14 ` Jeroen Van den Keybus
2015-04-22 5:14 ` Jan Kiszka [this message]
2015-04-22 19:22 ` Jeroen Van den Keybus
2015-04-28 19:12 ` Jeroen Van den Keybus
2015-04-29 6:36 ` Jan Kiszka
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=55372E49.10106@siemens.com \
--to=jan.kiszka@siemens.com \
--cc=jeroen.vandenkeybus@gmail.com \
--cc=xenomai@xenomai.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.